from typing import List, Optional
from sqlalchemy.orm import Session

from app.crud.base import CRUDBase
from app.models.genre import Genre
from app.schemas.genre import GenreCreate, GenreUpdate


class CRUDGenre(CRUDBase[Genre, GenreCreate, GenreUpdate]):
    def get_by_name(self, db: Session, *, name: str) -> Optional[Genre]:
        return db.query(Genre).filter(Genre.name == name).first()

    def get_multiple_by_ids(self, db: Session, *, ids: List[int]) -> List[Genre]:
        return db.query(Genre).filter(Genre.id.in_(ids)).all()


genre = CRUDGenre(Genre)